tuplettools.move_prolation_of_tuplet_to_contents_of_tuplet_and_remove_tuplet
============================================================================

.. autofunction:: abjad.tools.tuplettools.move_prolation_of_tuplet_to_contents_of_tuplet_and_remove_tuplet.move_prolation_of_tuplet_to_contents_of_tuplet_and_remove_tuplet
